api.assets.v1 package — Argus-Toolbelt 1.0 documentation

# api.assets.v1 package

## Submodules

## api.assets.v1.application module

Autogenerated API

`api.assets.v1.application.` `add_host_application`(hostID: str = None, roleID: int = None, name: str = None, description: str = None, properties: dict = None, cpe: str = None, sockets: list = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new HostApplication. (PUBLIC)

  Return type: | `dict`
  Parameters: | hostID (str) – Specify parent host. roleID (int) – Specify application role. name (str) – Name of application. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Description of application. => [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]* cpe (str) – CPE of application. sockets (list) – Specify socket strings of the application. source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 646, “limit”: 973, “responseCode”: 200, “count”: 404, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “House southern few reason allow gun life.”, “messageTemplate”: “Quite radio campaign over conference.”, “field”: “Not customer film official name thought.”, “parameter”: {}, “timestamp”: 1035190411}], “currentPage”: 159, “size”: 333}

`api.assets.v1.application.` `delete_host_application`(id: str, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a HostApplication as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostApplication ID source (str) – Request source (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 55, “limit”: 382, “responseCode”: 200, “count”: 114, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Agency rich do whose smile budget.”, “messageTemplate”: “Strong lay particular receive me ability table.”, “field”: “Foot free rate scientist.”, “parameter”: {}, “timestamp”: 841957888}], “currentPage”: 518, “size”: 381}

`api.assets.v1.application.` `get_host_application`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a HostApplication identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostApplication ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 208, “limit”: 94, “responseCode”: 200, “count”: 580, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Born century high kid.”, “messageTemplate”: “Professor maybe policy sign society smile.”, “field”: “Line great already put for physical performance.”, “parameter”: {}, “timestamp”: 861328090}], “currentPage”: 969, “size”: 504}

`api.assets.v1.application.` `search_host_application_statistics`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, applicationRole: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, groupBy: list = None, values: list = None, resolution: int = None, cutoff: int = None, cutoffValue: str = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeOthers: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch host application statistics base on criteria (DEV)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. applicationRole (list) – Search for applications by role (list of role IDs). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). groupBy (list) – Specify which fields will be grouped by in stats values (list) – Specify which values will be included in stats (default applications) resolution (int) – Stats resolution period in milliseconds, if is 0 means to generate non-timeline statistics cutoff (int) – Reduce stats keys to the cutoff amount of keys that has largest hit count, default 0 means no reduce cutoffValue (str) – Specify which value to be cutoff on (default applications) sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeOthers (bool) – If reduce (cutoff >0), true means remaining keys (other than cutoff keys) are collected into an “other” key, default false
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 492, “limit”: 464, “responseCode”: 200, “count”: 281, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Seat Democrat pass foreign forget over stage where.”, “messageTemplate”: “Fear purpose sound since sit suddenly.”, “field”: “Tough people authority seek.”, “parameter”: {}, “timestamp”: 519351006}], “currentPage”: 558, “size”: 307}

`api.assets.v1.application.` `search_host_applications`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, applicationRole: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of HostApplications defined by a HostApplicationSearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. applicationRole (list) – Search for applications by role (list of role IDs). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 18, “limit”: 612, “responseCode”: 200, “count”: 138, “data”: [{“id”: “Mr suddenly well scientist.”, “name”: “Michael Vega”, “description”: “Score assume cover whatever card per kind.”, “createdTimestamp”: 561388168, “createdByUser”: {“id”: 616, “customerID”: 847, “userName”: “fgonzalez”, “name”: “Stephen Davis”}, “lastUpdatedTimestamp”: 1391556029, “lastUpdatedByUser”: {“id”: 858, “customerID”: 234, “userName”: “thompsondale”, “name”: “Joshua Kent”}, “deletedTimestamp”: 1203663703, “deletedByUser”: {“id”: 315, “customerID”: 473, “userName”: “dennisblake”, “name”: “Jill Villa”}, “firstSeenTimestamp”: 996586131, “lastSeenTimestamp”: 848656206, “flags”: [“CREATED_BY_CVM”], “properties”: {“additionalProperties”: “Turn where over dark Mrs along quite.”}, “cpe”: “Back step travel magazine whether administration.”, “sockets”: [“Read central court agreement meeting.”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Huge put will town lawyer.”, “messageTemplate”: “Seven add cover kid local television.”, “field”: “Region social forward data national like word join.”, “parameter”: {}, “timestamp”: 1451710518}], “currentPage”: 355, “size”: 104}

`api.assets.v1.application.` `search_host_applications_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of HostApplications defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE includeFlag (list) – Include certain HostApplications in the search result based on set flags excludeFlag (list) – Exclude certain HostApplications from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 535, “limit”: 206, “responseCode”: 200, “count”: 950, “data”: [{“id”: “Decade end discover by own.”, “name”: “Taylor Lee”, “description”: “Realize TV event discuss.”, “createdTimestamp”: 1418935917, “createdByUser”: {“id”: 368, “customerID”: 359, “userName”: “browncarol”, “name”: “Kimberly Anderson”}, “lastUpdatedTimestamp”: 240093958, “lastUpdatedByUser”: {“id”: 406, “customerID”: 851, “userName”: “sheilalee”, “name”: “Cheryl Harris”}, “deletedTimestamp”: 1183715432, “deletedByUser”: {“id”: 990, “customerID”: 970, “userName”: “daniel81”, “name”: “Destiny Carey”}, “firstSeenTimestamp”: 138481663, “lastSeenTimestamp”: 133111939, “flags”: [“UPDATED_BY_CVM”], “properties”: {“additionalProperties”: “Return machine perform poor just tend.”}, “cpe”: “Recognize have red out maintain official wish.”, “sockets”: [“Loss occur I wonder go.”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Federal professor model no.”, “messageTemplate”: “Add include population risk pretty not stuff.”, “field”: “Work true gun pretty party.”, “parameter”: {}, “timestamp”: 1439986246}], “currentPage”: 992, “size”: 279}

`api.assets.v1.application.` `update_host_application`(id: str, roleID: int = None, name: str = None, description: str = None, addProperties: dict = None, deleteProperties: list = None, cpe: str = None, addSockets: list = None, deleteSockets: list = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing HostApplication. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostApplication ID roleID (int) – Change application role. name (str) – Change application name. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Change application description. => [sw{}$-().[]“‘_/,*+#:@!?;]* addProperties (dict) – Add properties to application (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Remove properties from application by key. cpe (str) – Change application CPE. addSockets (list) – Add sockets to application (list of protocol/port, e.g. tcp/80). deleteSockets (list) – Remove sockets from application (list of protocol/port, e.g. tcp/80). source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 587, “limit”: 266, “responseCode”: 200, “count”: 694, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Lay Republican center a stuff.”, “messageTemplate”: “Reach financial best we education.”, “field”: “Group federal pull least.”, “parameter”: {}, “timestamp”: 1415891034}], “currentPage”: 511, “size”: 777}

## api.assets.v1.businessprocess module

Autogenerated API

`api.assets.v1.businessprocess.` `add_business_process`(ownerID: int = None, customerID: int = None, name: str = None, description: str = None, properties: dict = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new BusinessProcess. (PUBLIC)

  Return type: | `dict`
  Parameters: | ownerID (int) – User who owns the asset. customerID (int) – Customer the asset belongs to. name (str) – Name of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Description of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 857, “limit”: 225, “responseCode”: 200, “count”: 240, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Area four main thousand tell foot.”, “messageTemplate”: “Key my assume lot.”, “field”: “She nothing word letter work itself.”, “parameter”: {}, “timestamp”: 1249065033}], “currentPage”: 719, “size”: 18}

`api.assets.v1.businessprocess.` `attach_services_to_business_process`(id: str, serviceAssetIDs: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Adds multiple ServiceAssets to a BusinessProcess. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID serviceAssetIDs (list) – Specify services to add to business process.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 200, “limit”: 821, “responseCode”: 200, “count”: 852, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Kitchen onto cause wonder.”, “messageTemplate”: “Long including sing.”, “field”: “The method sound.”, “parameter”: {}, “timestamp”: 1248004057}], “currentPage”: 572, “size”: 885}

`api.assets.v1.businessprocess.` `delete_business_process`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a BusinessProcess as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 629, “limit”: 421, “responseCode”: 200, “count”: 377, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Its drug smile apply.”, “messageTemplate”: “Nation heart could deal almost recent low.”, “field”: “Describe top effort race include few the something.”, “parameter”: {}, “timestamp”: 63669054}], “currentPage”: 444, “size”: 760}

`api.assets.v1.businessprocess.` `detach_services_from_business_process`(id: str, serviceAssetIDs: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Removes multiple ServiceAssets from a BusinessProcess. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID serviceAssetIDs (list) – Specify services to detach from business process.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 104, “limit”: 806, “responseCode”: 200, “count”: 590, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Explain member stop miss rate.”, “messageTemplate”: “Safe early environment happen medical however least.”, “field”: “Court task book behind case.”, “parameter”: {}, “timestamp”: 1203168942}], “currentPage”: 904, “size”: 922}

`api.assets.v1.businessprocess.` `get_business_process`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a BusinessProcess identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 974, “limit”: 799, “responseCode”: 200, “count”: 669, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Media yes since ever.”, “messageTemplate”: “Table hotel much house industry.”, “field”: “Serious official less hair level recognize shake.”, “parameter”: {}, “timestamp”: 170115065}], “currentPage”: 718, “size”: 884}

`api.assets.v1.businessprocess.` `search_business_process_statistics`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, ownerID: list = None, criticality: list = None, minimumTotalCvss: int = None, maximumTotalCvss: int = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, applicationRole: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, groupBy: list = None, values: list = None, resolution: int = None, cutoff: int = None, cutoffValue: str = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeOthers: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch business process statistics base on criteria (DEV)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. ownerID (list) – Restrict search to specific ownerIDs criticality (list) – Restrict search to a range of criticality levels (add multiple CriticalitySearch objects to specify OR criteria). minimumTotalCvss (int) – Restrict search to a minimum total CVSS score. maximumTotalCvss (int) – Restrict search to a maximum total CVSS score. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. applicationRole (list) – Restrict to applications with specific roles (list of role IDs). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp on business process). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). groupBy (list) – Specify which fields will be grouped by in stats values (list) – Specify which values will be included in stats (default processes) resolution (int) – Stats resolution period in milliseconds, if is 0 means to generate non-timeline statistics cutoff (int) – Reduce stats keys to the cutoff amount of keys that has largest hit count, default 0 means no reduce cutoffValue (str) – Specify which value to be cutoff on (default processes) sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeOthers (bool) – If reduce (cutoff >0), true means remaining keys (other than cutoff keys) are collected into an “other” key, default false
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 357, “limit”: 763, “responseCode”: 200, “count”: 876, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Hotel month hotel family near beat.”, “messageTemplate”: “Remember adult source relationship general.”, “field”: “House language grow sometimes than piece at.”, “parameter”: {}, “timestamp”: 752664502}], “currentPage”: 908, “size”: 6}

`api.assets.v1.businessprocess.` `search_business_processes`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, ownerID: list = None, criticality: list = None, minimumTotalCvss: int = None, maximumTotalCvss: int = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, applicationRole: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of BusinessProcesses defined by a BusinessProcessSearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. ownerID (list) – Restrict search to specific ownerIDs criticality (list) – Restrict search to a range of criticality levels (add multiple CriticalitySearch objects to specify OR criteria). minimumTotalCvss (int) – Restrict search to a minimum total CVSS score. maximumTotalCvss (int) – Restrict search to a maximum total CVSS score. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. applicationRole (list) – Restrict to applications with specific roles (list of role IDs). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp on business process). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 755, “limit”: 829, “responseCode”: 200, “count”: 41, “data”: [{“id”: “Apply consumer bag pull president road gun.”, “ownedByUser”: {“id”: 197, “customerID”: 333, “userName”: “hhickman”, “name”: “Joseph Lutz”}, “name”: “Amber Henry”, “description”: “Human morning interview bed.”, “totalCvss”: 866, “vulnerabilitiesCount”: 412, “createdTimestamp”: 158120863, “createdByUser”: {“id”: 732, “customerID”: 511, “userName”: “geraldrobles”, “name”: “Lisa Russell”}, “lastUpdatedTimestamp”: 645755284, “lastUpdatedByUser”: {“id”: 691, “customerID”: 568, “userName”: “timothy11”, “name”: “Benjamin Davila”}, “deletedTimestamp”: 1081251008, “deletedByUser”: {“id”: 327, “customerID”: 436, “userName”: “ronald49”, “name”: “Nancy Bowen”}, “flags”: [“UPDATED_BY_CVM”], “properties”: {“additionalProperties”: “Order from certainly late.”}, “services”: [{“id”: “Under tax role already will offer.”, “name”: “Kristin Montgomery”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Term return employee herself political matter.”, “messageTemplate”: “Start least heart matter loss ask give.”, “field”: “Hotel plant line agreement.”, “parameter”: {}, “timestamp”: 489828190}], “currentPage”: 165, “size”: 684}

`api.assets.v1.businessprocess.` `search_business_processes_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, vulnID: list = None, vulnRef: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns as set of BusinessProcesses defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE vulnID (list) – Search by vulnerability ID vulnRef (list) – Search by vulnerability reference includeFlag (list) – Include certain BusinessProcesses in the search result based on set flags excludeFlag (list) – Exclude certain BusinessProcesses from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 176, “limit”: 789, “responseCode”: 200, “count”: 468, “data”: [{“id”: “Movie money movement.”, “ownedByUser”: {“id”: 595, “customerID”: 391, “userName”: “zbird”, “name”: “Robert Ramos”}, “name”: “Joann Cooper”, “description”: “Another that participant authority.”, “totalCvss”: 880, “vulnerabilitiesCount”: 223, “createdTimestamp”: 931818552, “createdByUser”: {“id”: 483, “customerID”: 206, “userName”: “matthew40”, “name”: “Pamela Morales”}, “lastUpdatedTimestamp”: 319630967, “lastUpdatedByUser”: {“id”: 957, “customerID”: 449, “userName”: “mercadoalexa”, “name”: “William Mayo”}, “deletedTimestamp”: 810788377, “deletedByUser”: {“id”: 957, “customerID”: 729, “userName”: “egardner”, “name”: “Rachel Ballard”}, “flags”: [“MISSING_FROM_CVM”], “properties”: {“additionalProperties”: “Assume discuss along media do.”}, “services”: [{“id”: “Rock outside amount seven.”, “name”: “Kelly Woodard”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Democratic newspaper drive natural.”, “messageTemplate”: “Gun from professional situation professional provide democratic expect.”, “field”: “Republican town general similar kind theory.”, “parameter”: {}, “timestamp”: 665405880}], “currentPage”: 327, “size”: 5}

`api.assets.v1.businessprocess.` `update_business_process`(id: str, ownerID: int = None, name: str = None, description: str = None, addProperties: dict = None, deleteProperties: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing BusinessProcess. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – BusinessProcess ID ownerID (int) – Change user who owns the asset. name (str) – Change name of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Change description of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* addProperties (dict) – Add custom properties (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Delete custom properties by key.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 669, “limit”: 525, “responseCode”: 200, “count”: 10, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Seem significant recognize benefit store ahead.”, “messageTemplate”: “Most let decade reduce low.”, “field”: “Quickly check enough necessary also.”, “parameter”: {}, “timestamp”: 1244459957}], “currentPage”: 841, “size”: 763}

## api.assets.v1.host module

Autogenerated API

`api.assets.v1.host.` `add_host_asset`(ownerID: int = None, customerID: int = None, name: str = None, description: str = None, properties: dict = None, operatingSystemCPE: str = None, ipAddresses: list = None, aliases: list = None, type: str = 'SERVER', source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new HostAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | ownerID (int) – User who owns the asset. customerID (int) – Customer the asset belongs to. name (str) – Name of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Description of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]* operatingSystemCPE (str) – CPE of the host operating system. ipAddresses (list) – IP address(es) of the host. aliases (list) – Aliases (domain names) of the host. type (str) – Defines if host is a client or a server. (default SERVER) source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 265, “limit”: 616, “responseCode”: 200, “count”: 910, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Fine those themselves pull.”, “messageTemplate”: “Approach upon senior stop.”, “field”: “Still above open address simple few could.”, “parameter”: {}, “timestamp”: 1201734875}], “currentPage”: 463, “size”: 571}

`api.assets.v1.host.` `bulk_update_host_asset`(assetVulnerabilityAddRequests: list = None, assetVulnerabilityUpdateRequests: list = None, assetVulnerabilityResolveRequests: list = None, assetVulnerabilityDeleteRequests: list = None, hostApplicationAddRequests: list = None, hostApplicationUpdateRequests: list = None, hostApplicationDeleteRequests: list = None, hostAssetAddRequests: list = None, hostAssetUpdateRequests: list = None, hostAssetDeleteRequests: list = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Performs multiple updates to HostAssets in a single transaction. (PUBLIC)

  Return type: | `dict`
  Parameters: | assetVulnerabilityAddRequests (list) – List of AssetVulnerabilityAddRequests. assetVulnerabilityUpdateRequests (list) – List of AssetVulnerabilityUpdateRequests. assetVulnerabilityResolveRequests (list) – List of AssetVulnerabilityResolveRequests. assetVulnerabilityDeleteRequests (list) – List of AssetVulnerabilityDeleteRequests. hostApplicationAddRequests (list) – List of HostApplicationAddRequests. hostApplicationUpdateRequests (list) – List of HostApplicationUpdateRequests. hostApplicationDeleteRequests (list) – List of HostApplicationDeleteRequests. hostAssetAddRequests (list) – List of HostAssetAddRequests. Adding vulnerabilities/applications to added hosts must be done in separate transaction. hostAssetUpdateRequests (list) – List of HostAssetUpdateRequests. hostAssetDeleteRequests (list) – List of HostAssetDeleteRequests. source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 167, “limit”: 687, “responseCode”: 200, “count”: 180, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Already character response present shake easy daughter break.”, “messageTemplate”: “Notice notice parent first seat determine.”, “field”: “Phone example each lot son anything product.”, “parameter”: {}, “timestamp”: 1169025703}], “currentPage”: 158, “size”: 968}

`api.assets.v1.host.` `delete_host_asset`(id: str, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a HostAsset as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostAsset ID source (str) – Request source (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 257, “limit”: 416, “responseCode”: 200, “count”: 317, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “West rate away production.”, “messageTemplate”: “Player network catch fire start lot.”, “field”: “Case group white drug.”, “parameter”: {}, “timestamp”: 1292084013}], “currentPage”: 986, “size”: 342}

`api.assets.v1.host.` `get_host_asset`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a HostAsset identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostAsset ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 962, “limit”: 214, “responseCode”: 200, “count”: 767, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Open health question.”, “messageTemplate”: “Dream red citizen certain.”, “field”: “Perform than movie loss score floor everything behind.”, “parameter”: {}, “timestamp”: 1448827563}], “currentPage”: 41, “size”: 178}

`api.assets.v1.host.` `merge_host_asset`(mergeIntoID: str, mergeFromID: list = None, ownerID: int = None, name: str = None, description: str = None, type: str = None, operatingSystemCPE: str = None, mergeApplications: bool = 'False', mergeVulnerabilities: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Merges multiple HostAssets into one. (DEV) This operation takes multiple HostAssets (merge from) and merges them into another existing HostAsset (merge into). Thereby collection fields from all HostAssets are combined by calculating their union. Conflicts between single value fields can be resolved manually by explicitly specifying the values to use in the request. By default the values from the merge into HostAsset will be retained. When ‘mergeApplications’ or ‘mergeVulnerabilities’ are set in the request applications and vulnerabilities are merged as well, i.e. all applications and vulnerabilities from all HostAssets will be present in the merge result. But duplicated applications and vulnerabilities will be omitted.

  Return type: | `dict`

`api.assets.v1.host.` `search_host_asset_statistics`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, ownerID: list = None, criticality: list = None, minimumTotalCvss: int = None, maximumTotalCvss: int = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, applicationRole: list = None, type: str = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, groupBy: list = None, values: list = None, resolution: int = None, cutoff: int = None, cutoffValue: str = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeVulnerabilityRawOutput: bool = 'False', includeVulnerabilityConclusion: bool = 'False', includeVulnerabilitySolution: bool = 'False', includeVulnerabilities: bool = 'False', includeApplications: bool = 'False', includeServices: bool = 'False', connectedToService: bool = 'False', includeOthers: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch host asset statistics base on criteria (DEV)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. ownerID (list) – Restrict search to specific ownerIDs criticality (list) – Restrict search to a range of criticality levels (add multiple CriticalitySearch objects to specify OR criteria). minimumTotalCvss (int) – Restrict search to a minimum total CVSS score. maximumTotalCvss (int) – Restrict search to a maximum total CVSS score. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. applicationRole (list) – Restrict to applications with specific roles (list of role IDs). type (str) – Restrict search to a specific type of host (client or server). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp on host). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). groupBy (list) – Specify which fields will be grouped by in stats values (list) – Specify which values will be included in stats (default hosts) resolution (int) – Stats resolution period in milliseconds, if is 0 means to generate non-timeline statistics cutoff (int) – Reduce stats keys to the cutoff amount of keys that has largest hit count, default 0 means no reduce cutoffValue (str) – Specify which value to be cutoff on (default hosts) sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeVulnerabilityRawOutput (bool) – Include vulnerability rawOutput in result (default false). includeVulnerabilityConclusion (bool) – Include vulnerability conclusion in result (default false). includeVulnerabilitySolution (bool) – Include vulnerability solution in result (default false). includeVulnerabilities (bool) – Include host vulnerabilities in result (default false). includeApplications (bool) – Include host applications in result (default false). includeServices (bool) – Include related services in result (default false). connectedToService (bool) – If true, only return hosts connected to service(s). If false, return hosts not connected to any service. If not set, do not filter. includeOthers (bool) – If reduce (cutoff>0), true means remaining keys (other than cutoff keys) are collected into an “other” key, default false
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 435, “limit”: 27, “responseCode”: 200, “count”: 348, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Always office voice necessary continue mind owner.”, “messageTemplate”: “Purpose property first spring day head popular leg.”, “field”: “South sort real with own choice.”, “parameter”: {}, “timestamp”: 1350778850}], “currentPage”: 663, “size”: 667}

`api.assets.v1.host.` `search_host_assets`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, ownerID: list = None, criticality: list = None, minimumTotalCvss: int = None, maximumTotalCvss: int = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, applicationRole: list = None, type: str = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeVulnerabilityRawOutput: bool = 'False', includeVulnerabilityConclusion: bool = 'False', includeVulnerabilitySolution: bool = 'False', includeVulnerabilities: bool = 'False', includeApplications: bool = 'False', includeServices: bool = 'False', connectedToService: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of HostAssets defined by a HostAssetSearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. ownerID (list) – Restrict search to specific ownerIDs criticality (list) – Restrict search to a range of criticality levels (add multiple CriticalitySearch objects to specify OR criteria). minimumTotalCvss (int) – Restrict search to a minimum total CVSS score. maximumTotalCvss (int) – Restrict search to a maximum total CVSS score. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. applicationRole (list) – Restrict to applications with specific roles (list of role IDs). type (str) – Restrict search to a specific type of host (client or server). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp on host). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeVulnerabilityRawOutput (bool) – Include vulnerability rawOutput in result (default false). includeVulnerabilityConclusion (bool) – Include vulnerability conclusion in result (default false). includeVulnerabilitySolution (bool) – Include vulnerability solution in result (default false). includeVulnerabilities (bool) – Include host vulnerabilities in result (default false). includeApplications (bool) – Include host applications in result (default false). includeServices (bool) – Include related services in result (default false). connectedToService (bool) – If true, only return hosts connected to service(s). If false, return hosts not connected to any service. If not set, do not filter.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 198, “limit”: 940, “responseCode”: 200, “count”: 211, “data”: [{“id”: “Tend money able second nor rule forward.”, “ownedByUser”: {“id”: 139, “customerID”: 622, “userName”: “kylemorgan”, “name”: “Matthew Taylor”}, “name”: “Jeffrey Bennett”, “description”: “Their know knowledge indeed road rise.”, “totalCvss”: 708, “vulnerabilitiesCount”: 457, “createdTimestamp”: 61015847, “createdByUser”: {“id”: 271, “customerID”: 32, “userName”: “jason95”, “name”: “Mary Beltran”}, “lastUpdatedTimestamp”: 1092044753, “lastUpdatedByUser”: {“id”: 151, “customerID”: 148, “userName”: “andrew04”, “name”: “Andrew Meadows Jr.”}, “deletedTimestamp”: 162626303, “deletedByUser”: {“id”: 550, “customerID”: 282, “userName”: “xperez”, “name”: “Eric Campbell”}, “flags”: [“HAS_CRITICAL_VULN”], “properties”: {“additionalProperties”: “International sport team member analysis tell.”}, “firstSeenTimestamp”: 568100759, “lastSeenTimestamp”: 1276880961, “lastScanTimestamp”: 1385297650, “ipAddresses”: [{“host”: false, “maskBits”: 863, “ipv6”: false, “multicast”: true, “public”: false, “address”: “Environmental involve save sound but.”}], “aliases”: [{“fqdn”: “Follow hour long usually task.”}], “services”: [{“id”: “Throw imagine cause two exactly movement.”, “name”: “William Schmidt MD”}], “applications”: [{“id”: “Ok left election consumer trade baby add.”, “name”: “Melissa Moore”, “description”: “Or different tend.”, “createdTimestamp”: 1431935484, “lastUpdatedTimestamp”: 8046609, “deletedTimestamp”: 1269105144, “firstSeenTimestamp”: 547820373, “lastSeenTimestamp”: 39114406, “flags”: [“DETECTED_BY_CVM”], “properties”: {“additionalProperties”: “Wife before push material dog education stock.”}, “cpe”: “Simply method black information rest teach.”, “sockets”: [“Much office whom hospital present.”]}], “vulnerabilities”: [{“id”: “Matter tree under.”, “vulnerabilityID”: “Of decision public including radio red.”, “references”: [“Sound entire memory morning property where.”], “name”: “Gail Boone”, “description”: “Why term as marriage industry guess.”, “conclusion”: “Head property only west discover them explain.”, “solution”: “Forward crime your mind piece.”, “rawOutput”: “Every example check if.”, “cvss”: 341, “createdTimestamp”: 1479129802, “lastUpdatedTimestamp”: 1349061627, “deletedTimestamp”: 1177382495, “firstSeenTimestamp”: 433408019, “lastSeenTimestamp”: 300980805, “resolutionTimestamp”: 547649331, “resolutionComment”: “Black respond think prove.”, “resolution”: “UNRESOLVED”, “flags”: [“UPDATED_BY_CVM”], “properties”: {“additionalProperties”: “Floor myself section charge rather he.”}, “severity”: “critical”, “socket”: “Minute method lawyer happy data use read.”}], “operatingSystemCPE”: “Paper night by term skill available attorney.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Week stand receive detail total data talk.”, “messageTemplate”: “Like note must base maintain put rock.”, “field”: “Truth loss billion hotel best.”, “parameter”: {}, “timestamp”: 955336348}], “currentPage”: 950, “size”: 210}

`api.assets.v1.host.` `search_host_assets_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, vulnID: list = None, vulnRef: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns as set of HostAssets defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE vulnID (list) – Search by vulnerability ID vulnRef (list) – Search by vulnerability reference includeFlag (list) – Include certain HostAssets in the search result based on set flags excludeFlag (list) – Exclude certain HostAssets from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 841, “limit”: 647, “responseCode”: 200, “count”: 805, “data”: [{“id”: “Star affect plan throughout company property they.”, “ownedByUser”: {“id”: 217, “customerID”: 28, “userName”: “ncooper”, “name”: “Mrs. Mary Simpson MD”}, “name”: “Mark Costa”, “description”: “Everybody sort week first thought offer argue.”, “totalCvss”: 56, “vulnerabilitiesCount”: 931, “createdTimestamp”: 290430372, “createdByUser”: {“id”: 123, “customerID”: 256, “userName”: “mary60”, “name”: “Sandra Cardenas”}, “lastUpdatedTimestamp”: 229308672, “lastUpdatedByUser”: {“id”: 422, “customerID”: 330, “userName”: “lynnsnyder”, “name”: “Mark Clarke”}, “deletedTimestamp”: 829094186, “deletedByUser”: {“id”: 32, “customerID”: 694, “userName”: “pbarnett”, “name”: “Levi Robinson”}, “flags”: [“MISSING_FROM_CVM”], “properties”: {“additionalProperties”: “She enter nor officer rule sure leader listen.”}, “firstSeenTimestamp”: 423075681, “lastSeenTimestamp”: 1143425246, “lastScanTimestamp”: 194972342, “ipAddresses”: [{“host”: true, “maskBits”: 478, “ipv6”: false, “multicast”: false, “public”: true, “address”: “Soldier laugh control green.”}], “aliases”: [{“fqdn”: “Case reflect himself inside guy believe event.”}], “services”: [{“id”: “Dinner certain teacher building camera off action.”, “name”: “Joshua Kirk”}], “applications”: [{“id”: “Sell success today surface all specific.”, “name”: “Elizabeth Higgins”, “description”: “Body music short his case television nation.”, “createdTimestamp”: 1447508668, “lastUpdatedTimestamp”: 768433844, “deletedTimestamp”: 446898952, “firstSeenTimestamp”: 315556943, “lastSeenTimestamp”: 1309029447, “flags”: [“DELETED_FROM_CVM”], “properties”: {“additionalProperties”: “Main hospital anyone family here require ago.”}, “cpe”: “Go same three age.”, “sockets”: [“Themselves family over parent.”]}], “vulnerabilities”: [{“id”: “Could prepare among parent western job.”, “vulnerabilityID”: “Identify surface bad as identify.”, “references”: [“Fly within very successful great traditional study.”], “name”: “David Rangel”, “description”: “Medical matter challenge care determine talk.”, “conclusion”: “Record up up take owner conference enter.”, “solution”: “More reflect skill lose room fire international.”, “rawOutput”: “East word after soon commercial ever.”, “cvss”: 272, “createdTimestamp”: 735056444, “lastUpdatedTimestamp”: 1430359039, “deletedTimestamp”: 30896796, “firstSeenTimestamp”: 1444676242, “lastSeenTimestamp”: 1347887822, “resolutionTimestamp”: 1045222323, “resolutionComment”: “Service five ten anything.”, “resolution”: “ACCEPTED”, “flags”: [“DELETED_FROM_CVM”], “properties”: {“additionalProperties”: “Through which process sport successful.”}, “severity”: “critical”, “socket”: “Young state those.”}], “operatingSystemCPE”: “Whose daughter note increase.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Top notice speak form seem.”, “messageTemplate”: “Official southern through always budget family themselves.”, “field”: “Federal policy maybe remember charge court.”, “parameter”: {}, “timestamp”: 1262639108}], “currentPage”: 141, “size”: 575}

`api.assets.v1.host.` `update_host_asset`(id: str, ownerID: int = None, name: str = None, description: str = None, addProperties: dict = None, deleteProperties: list = None, type: str = None, operatingSystemCPE: str = None, addIpAddresses: list = None, deleteIpAddresses: list = None, addAliases: list = None, deleteAliases: list = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing HostAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – HostAsset ID ownerID (int) – Change user who owns the asset. name (str) – Change name of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Change description of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* addProperties (dict) – Add custom properties (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Delete custom properties by key. type (str) – Change type of host (client or server). operatingSystemCPE (str) – Change CPE of host. addIpAddresses (list) – Add IP address(es) to host. deleteIpAddresses (list) – Delete IP address(es) from host. addAliases (list) – Add alias(es) (domain names) to host. deleteAliases (list) – Delete alias(es) from host. source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 749, “limit”: 766, “responseCode”: 200, “count”: 905, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “In still summer.”, “messageTemplate”: “Else couple unit parent listen family.”, “field”: “Sea tonight girl line.”, “parameter”: {}, “timestamp”: 586769306}], “currentPage”: 168, “size”: 552}

## api.assets.v1.scan module

Autogenerated API

`api.assets.v1.scan.` `host_asset_bulk_scanned`(customerID: int = None, scannedRequests: list = None, scannedIpRanges: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks multiple HostAsset as scanned. (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – Define customer which was scanned. scannedRequests (list) – Set of host scan requests. scannedIpRanges (list) – Set of scanned IP address ranges as list of single IPs (1.1.1.1), CIDR networks (1.1.1.0/24) or ranges (1.1.1.1-1.1.1.2)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 530, “limit”: 84, “responseCode”: 200, “count”: 367, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Protect rule leave sell itself out.”, “messageTemplate”: “Ball laugh mother task spring.”, “field”: “Population soon author consumer.”, “parameter”: {}, “timestamp”: 883500667}], “currentPage”: 640, “size”: 307}

`api.assets.v1.scan.` `host_asset_scanned`(customerID: int, ip: str, detectedVulnerabilities: list = None, detectedApplications: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a single HostAsset as scanned. (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – Customer ID ip (str) – IP address of scanned HostAsset detectedVulnerabilities (list) – Specify (vulnerabilityID, socket string) objects of detected vulnerabilities. detectedApplications (list) – Specify sockets of detected applications (e.g. tcp/80).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 167, “limit”: 42, “responseCode”: 200, “count”: 453, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Available once machine just.”, “messageTemplate”: “Form top camera fish usually.”, “field”: “Require husband ever ok everyone American.”, “parameter”: {}, “timestamp”: 1248221392}], “currentPage”: 748, “size”: 159}

## api.assets.v1.service module

Autogenerated API

`api.assets.v1.service.` `add_service_asset`(ownerID: int = None, customerID: int = None, name: str = None, description: str = None, properties: dict = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new ServiceAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | ownerID (int) – User who owns the asset. customerID (int) – Customer the asset belongs to. name (str) – Name of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Description of the asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]*
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 928, “limit”: 165, “responseCode”: 200, “count”: 547, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Movement type summer language or.”, “messageTemplate”: “Worry huge newspaper wind debate care city.”, “field”: “Able in bit claim between different tell.”, “parameter”: {}, “timestamp”: 103181045}], “currentPage”: 197, “size”: 835}

`api.assets.v1.service.` `attach_hosts_to_service`(id: str, hostAssetIDs: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Adds multiple HostAssets to a ServiceAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID hostAssetIDs (list) – Specify hosts to add to service.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 480, “limit”: 536, “responseCode”: 200, “count”: 805, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Down everybody strategy expert citizen suffer picture.”, “messageTemplate”: “Red especially create professional country room under.”, “field”: “Mr yourself blood next.”, “parameter”: {}, “timestamp”: 761728055}], “currentPage”: 270, “size”: 651}

`api.assets.v1.service.` `delete_service_asset`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks a ServiceAsset as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 829, “limit”: 915, “responseCode”: 200, “count”: 842, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Girl run star.”, “messageTemplate”: “Condition reach reach to themselves decide.”, “field”: “Reduce break maybe attention nature debate else little.”, “parameter”: {}, “timestamp”: 319520432}], “currentPage”: 665, “size”: 238}

`api.assets.v1.service.` `detach_hosts_from_service`(id: str, hostAssetIDs: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Removes multiple HostAssets from a ServiceAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID hostAssetIDs (list) – Specify hosts to detach from service.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 492, “limit”: 130, “responseCode”: 200, “count”: 723, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Leader attack watch young may total.”, “messageTemplate”: “Environment apply name view.”, “field”: “Defense body yourself number bill offer.”, “parameter”: {}, “timestamp”: 1271668574}], “currentPage”: 309, “size”: 4}

`api.assets.v1.service.` `get_service_asset`(id: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a ServiceAsset identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 848, “limit”: 4, “responseCode”: 200, “count”: 437, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Authority set billion rule.”, “messageTemplate”: “Sell film similar.”, “field”: “Less audience throughout adult trial.”, “parameter”: {}, “timestamp”: 935446071}], “currentPage”: 753, “size”: 148}

`api.assets.v1.service.` `search_service_asset_statistics`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, ownerID: list = None, criticality: list = None, minimumTotalCvss: int = None, maximumTotalCvss: int = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, applicationRole: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, groupBy: list = None, values: list = None, resolution: int = None, cutoff: int = None, cutoffValue: str = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeOthers: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch service asset statistics base on criteria (DEV)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. ownerID (list) – Restrict search to specific ownerIDs criticality (list) – Restrict search to a range of criticality levels (add multiple CriticalitySearch objects to specify OR criteria). minimumTotalCvss (int) – Restrict search to a minimum total CVSS score. maximumTotalCvss (int) – Restrict search to a maximum total CVSS score. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. applicationRole (list) – Restrict to applications with specific roles (list of role IDs). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp on service). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). groupBy (list) – Specify which fields will be grouped by in stats values (list) – Specify which values will be included in stats (default services) resolution (int) – Stats resolution period in milliseconds, if is 0 means to generate non-timeline statistics cutoff (int) – Reduce stats keys to the cutoff amount of keys that has largest hit count, default 0 means no reduce cutoffValue (str) – Specify which value to be cutoff on (default services) sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeOthers (bool) – If reduce (cutoff >0), true means remaining keys (other than cutoff keys) are collected into an “other” key, default false
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 927, “limit”: 671, “responseCode”: 200, “count”: 753, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Much husband that protect people remain right Mrs.”, “messageTemplate”: “Agree upon capital if loss two perform.”, “field”: “Off audience nature turn else check clearly.”, “parameter”: {}, “timestamp”: 406767066}], “currentPage”: 306, “size”: 201}

`api.assets.v1.service.` `search_service_assets`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, ownerID: list = None, criticality: list = None, minimumTotalCvss: int = None, maximumTotalCvss: int = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, applicationRole: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of ServiceAssets defined by a ServiceAssetSearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. ownerID (list) – Restrict search to specific ownerIDs criticality (list) – Restrict search to a range of criticality levels (add multiple CriticalitySearch objects to specify OR criteria). minimumTotalCvss (int) – Restrict search to a minimum total CVSS score. maximumTotalCvss (int) – Restrict search to a maximum total CVSS score. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. applicationRole (list) – Restrict to applications with specific roles (list of role IDs). timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp on service). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 241, “limit”: 928, “responseCode”: 200, “count”: 415, “data”: [{“id”: “Year nice indicate finish pick above.”, “ownedByUser”: {“id”: 794, “customerID”: 321, “userName”: “ericamoody”, “name”: “George Smith”}, “name”: “Patricia Reid”, “description”: “Only table yet available.”, “totalCvss”: 714, “vulnerabilitiesCount”: 154, “createdTimestamp”: 449553080, “createdByUser”: {“id”: 808, “customerID”: 94, “userName”: “xyoung”, “name”: “Lisa Orozco”}, “lastUpdatedTimestamp”: 605814776, “lastUpdatedByUser”: {“id”: 440, “customerID”: 402, “userName”: “jeffrey61”, “name”: “Timothy Stewart DDS”}, “deletedTimestamp”: 225006377, “deletedByUser”: {“id”: 723, “customerID”: 71, “userName”: “valdezjeremiah”, “name”: “Yvette Harrison”}, “flags”: [“HAS_HIGH_VULN”], “properties”: {“additionalProperties”: “Mean mouth opportunity will Congress effort.”}, “businessProcesses”: [{“id”: “Paper need take medical one wife.”, “name”: “Jason Taylor”}], “hosts”: [{“id”: “Positive space trouble.”, “name”: “Danielle Cross”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Executive near design.”, “messageTemplate”: “Town rock actually blue.”, “field”: “Boy project bar walk.”, “parameter”: {}, “timestamp”: 853375290}], “currentPage”: 886, “size”: 574}

`api.assets.v1.service.` `search_service_assets_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, vulnID: list = None, vulnRef: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns as set of ServiceAssets defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE vulnID (list) – Search by vulnerability ID vulnRef (list) – Search by vulnerability reference includeFlag (list) – Include certain ServiceAssets in the search result based on set flags excludeFlag (list) – Exclude certain ServiceAssets from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 205, “limit”: 614, “responseCode”: 200, “count”: 37, “data”: [{“id”: “Different some born.”, “ownedByUser”: {“id”: 879, “customerID”: 305, “userName”: “ldavidson”, “name”: “Joseph Martin”}, “name”: “Beverly Gonzalez”, “description”: “South exist east draw.”, “totalCvss”: 729, “vulnerabilitiesCount”: 942, “createdTimestamp”: 131281339, “createdByUser”: {“id”: 386, “customerID”: 631, “userName”: “christopher31”, “name”: “Melanie Villegas”}, “lastUpdatedTimestamp”: 272996152, “lastUpdatedByUser”: {“id”: 478, “customerID”: 158, “userName”: “unichols”, “name”: “Bethany Bauer DDS”}, “deletedTimestamp”: 1157213869, “deletedByUser”: {“id”: 945, “customerID”: 359, “userName”: “paynecheryl”, “name”: “Dr. Valerie Spencer DDS”}, “flags”: [“UPDATED_BY_CVM”], “properties”: {“additionalProperties”: “Large heavy part.”}, “businessProcesses”: [{“id”: “Those worry eight professional south.”, “name”: “David Mooney”}], “hosts”: [{“id”: “Window two soldier call he another.”, “name”: “Joshua Wilson”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Produce purpose direction nation choose everybody attorney.”, “messageTemplate”: “Simply compare himself staff without.”, “field”: “Theory stand in age compare unit state.”, “parameter”: {}, “timestamp”: 495414401}], “currentPage”: 635, “size”: 217}

`api.assets.v1.service.` `update_service_asset`(id: str, ownerID: int = None, name: str = None, description: str = None, addProperties: dict = None, deleteProperties: list = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing ServiceAsset. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – ServiceAsset ID ownerID (int) – Change user who owns the asset. name (str) – Change name of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* description (str) – Change description of asset. => [sw{}$-().[]“‘_/,*+#:@!?;]* addProperties (dict) – Add custom properties (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Delete custom properties by key.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 6, “limit”: 806, “responseCode”: 200, “count”: 284, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Third result address.”, “messageTemplate”: “Toward standard campaign above forget Republican care.”, “field”: “Argue region surface when.”, “parameter”: {}, “timestamp”: 534706606}], “currentPage”: 291, “size”: 8}

## api.assets.v1.vulnerability module

Autogenerated API

`api.assets.v1.vulnerability.` `add_asset_vulnerability`(hostID: str = None, vulnerabilityID: str = None, references: list = None, name: str = None, description: str = None, conclusion: str = None, solution: str = None, rawOutput: str = None, cvss: int = None, severity: str = None, properties: dict = None, socket: str = None, source: str = 'USER', exploitAvailable: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Creates a new AssetVulnerability. (PUBLIC)

  Return type: | `dict`
  Parameters: | hostID (str) – Specify parent host. vulnerabilityID (str) – Identifier of vulnerability (e.g. plug-in ID from vulnerability scanner). => [sw{}$-().[]“‘_/,*+#:@!?;]* references (list) – References to vulnerability (e.g. CVE number). name (str) – Name of vulnerability. Will be sanitized and no line break allowed. description (str) – Description of vulnerability. Will be sanitized. conclusion (str) – Short summary of vulnerability. Will be sanitized. solution (str) – How to fix vulnerability. Will be sanitized. rawOutput (str) – Raw output from vulnerability scan. Will be sanitized. cvss (int) – CVSS score of vulnerability (range from 0 to 10). severity (str) – Severity level of vulnerability. properties (dict) – Custom user-defined properties. => [sw{}$-().[]“‘_/,*+#:@!?;]* socket (str) – Specify socket string of the vulnerability (e.g. tcp/80), or omit if not bound to a socket. source (str) – Source of the request. (default USER) exploitAvailable (bool) – Set if an exploit is available for the vulnerability.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 205, “limit”: 618, “responseCode”: 200, “count”: 484, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Maintain determine join support.”, “messageTemplate”: “Word pretty however important.”, “field”: “Trip keep writer policy huge.”, “parameter”: {}, “timestamp”: 712057104}], “currentPage”: 544, “size”: 237}

`api.assets.v1.vulnerability.` `delete_asset_vulnerability`(id: str, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Marks an AssetVulnerability as deleted. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – AssetVulnerability ID source (str) – Request source (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 784, “limit”: 500, “responseCode”: 200, “count”: 957, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Around political popular.”, “messageTemplate”: “Need view public energy.”, “field”: “Board kind worker box successful paper fear.”, “parameter”: {}, “timestamp”: 962464163}], “currentPage”: 596, “size”: 275}

`api.assets.v1.vulnerability.` `get_asset_vulnerability`(id: str, includeRawOutput: bool = 'True', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns an AssetVulnerability identified by its ID. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – AssetVulnerability ID includeRawOutput (bool) – Include raw output
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 727, “limit”: 963, “responseCode”: 200, “count”: 269, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Capital figure officer.”, “messageTemplate”: “Subject course room yourself.”, “field”: “Staff also director unit seem.”, “parameter”: {}, “timestamp”: 438407466}], “currentPage”: 176, “size”: 27}

`api.assets.v1.vulnerability.` `resolve_asset_vulnerability`(id: str, resolution: str = None, comment: str = None, source: str = 'USER', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Resolves an AssetVulnerability. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – AssetVulnerability ID resolution (str) – Specify resolution reason. comment (str) – Comment on why the vulnerability is resolved. => [sw{}$-().[]“‘_/,*+#:@!?;]* source (str) – Source of the request. (default USER)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 334, “limit”: 422, “responseCode”: 200, “count”: 668, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Hospital happy future dark ok ready break area.”, “messageTemplate”: “Green window far art us eye.”, “field”: “Same house whom point but cost site wear.”, “parameter”: {}, “timestamp”: 802734828}], “currentPage”: 596, “size”: 343}

`api.assets.v1.vulnerability.` `search_asset_vulnerabilities`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, minimumCvss: int = None, maximumCvss: int = None, severity: list = None, resolutionCode: list = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeRawOutput: bool = 'False', includeConclusion: bool = 'False', includeSolution: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns a set of AssetVulnerabilities defined by an AssetVulnerabilitySearchCriteria. (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. minimumCvss (int) – Restrict search to vulnerabilities with CVSS score at least this high. maximumCvss (int) – Restrict search to vulnerabilities with CVSS score no more than this. severity (list) – Restrict search to specified severity levels. resolutionCode (list) – Restrict search to specific resolution codes. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeRawOutput (bool) – Include vulnerability rawOutput in result (default false) includeConclusion (bool) – Include vulnerability conclusion in result (default false) includeSolution (bool) – Include vulnerability solution in result (default false)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 824, “limit”: 315, “responseCode”: 200, “count”: 446, “data”: [{“id”: “Hold sing world hit laugh PM federal.”, “vulnerabilityID”: “In law individual today middle activity.”, “references”: [“Research heart off quickly go people brother.”], “name”: “Patricia Morales”, “description”: “Response history hundred seek growth.”, “conclusion”: “Wall charge pull hand.”, “solution”: “Else seem some mean.”, “rawOutput”: “There ground treat same.”, “cvss”: 128, “createdTimestamp”: 1298798831, “createdByUser”: {“id”: 347, “customerID”: 553, “userName”: “qmorgan”, “name”: “Beverly Allen”}, “lastUpdatedTimestamp”: 967414679, “lastUpdatedByUser”: {“id”: 440, “customerID”: 420, “userName”: “paul99”, “name”: “Gabriel Martin”}, “deletedTimestamp”: 299746488, “deletedByUser”: {“id”: 681, “customerID”: 7, “userName”: “timothy74”, “name”: “Cody Rodriguez”}, “firstSeenTimestamp”: 999216036, “lastSeenTimestamp”: 34600864, “resolutionTimestamp”: 52201804, “resolvedByUser”: {“id”: 290, “customerID”: 848, “userName”: “ambermathews”, “name”: “Daniel Carrillo”}, “resolutionComment”: “Become thought drug section apply.”, “resolution”: “FALSE_POSITIVE”, “flags”: [“UPDATED_BY_CVM”], “properties”: {“additionalProperties”: “Talk suffer list admit herself continue any.”}, “severity”: “low”, “socket”: “Receive which idea less always.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Work sound study social form part check choice.”, “messageTemplate”: “Language subject police civil little interesting interest.”, “field”: “Job partner small all.”, “parameter”: {}, “timestamp”: 1440263576}], “currentPage”: 186, “size”: 126}

`api.assets.v1.vulnerability.` `search_asset_vulnerabilities_simplified`(keywords: list = None, keywordField: list = None, name: list = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, customerID: list = None, ip: list = None, port: list = None, protocol: list = None, cpe: list = None, vulnID: list = None, vulnRef: list = None, resolutionCode: list = None, includeFlag: list = None, excludeFlag: list = None, sortBy: list = None, offset: int = 0, limit: int = 25, keywordMatch: str = 'all', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Returns as set of AssetVulnerabilities defined by query parameters. (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Search by keywords keywordField (list) – Set field strategy for keyword search name (list) – Search by name hostID (list) – Search by HostAsset ID serviceID (list) – Search by ServiceAsset ID businessProcessID (list) – Search by BusinessProcess ID customerID (list) – Search by customer ID ip (list) – Search by IP range port (list) – Search by application port protocol (list) – Search by application protocol cpe (list) – Search by CPE vulnID (list) – Search by vulnerability ID vulnRef (list) – Search by vulnerability reference resolutionCode (list) – Search by resolution code includeFlag (list) – Include certain BusinessProcesses in the search result based on set flags excludeFlag (list) – Exclude certain BusinessProcesses from the search result based on set flags sortBy (list) – Sort search result offset (int) – Skip a number of results limit (int) – Maximum number of returned results keywordMatch (str) – Set match strategy for keyword search
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 450, “limit”: 184, “responseCode”: 200, “count”: 875, “data”: [{“id”: “His home increase hair senior.”, “vulnerabilityID”: “Accept activity radio teacher cover interview.”, “references”: [“Whether professional talk begin range.”], “name”: “Alyssa Martinez”, “description”: “Play season something officer maybe.”, “conclusion”: “Base college success else very across.”, “solution”: “Prevent floor project hair mother picture indicate.”, “rawOutput”: “Detail stay your as.”, “cvss”: 680, “createdTimestamp”: 953427274, “createdByUser”: {“id”: 216, “customerID”: 221, “userName”: “kevinmatthews”, “name”: “Brian Jones”}, “lastUpdatedTimestamp”: 1316362350, “lastUpdatedByUser”: {“id”: 906, “customerID”: 810, “userName”: “johnduncan”, “name”: “Jonathan Powell”}, “deletedTimestamp”: 851035837, “deletedByUser”: {“id”: 785, “customerID”: 873, “userName”: “tpowell”, “name”: “Michael Knight PhD”}, “firstSeenTimestamp”: 16298616, “lastSeenTimestamp”: 592701842, “resolutionTimestamp”: 278356871, “resolvedByUser”: {“id”: 22, “customerID”: 324, “userName”: “jessica58”, “name”: “Laura Lewis”}, “resolutionComment”: “Fight current way fly hand.”, “resolution”: “SERVICE_NOT_AVAILABLE”, “flags”: [“DETECTED_BY_CVM”], “properties”: {“additionalProperties”: “World foot similar contain government since speech.”}, “severity”: “critical”, “socket”: “Sort force information article treat.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Camera realize begin might remain adult.”, “messageTemplate”: “Despite apply there through anyone job chair.”, “field”: “Various will station medical.”, “parameter”: {}, “timestamp”: 905979064}], “currentPage”: 172, “size”: 572}

`api.assets.v1.vulnerability.` `search_asset_vulnerability_statistics`(limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, name: list = None, startTimestamp: int = None, endTimestamp: int = None, keywords: list = None, keywordMatchStrategy: str = None, timeMatchStrategy: str = None, hostID: list = None, serviceID: list = None, businessProcessID: list = None, ipRange: list = None, applicationPort: list = None, applicationProtocol: list = None, cpe: list = None, hostCPE: list = None, applicationCPE: list = None, minimumCvss: int = None, maximumCvss: int = None, severity: list = None, resolutionCode: list = None, vulnerabilityReference: list = None, vulnerabilityID: list = None, timeFieldStrategy: list = None, keywordFieldStrategy: list = None, groupBy: list = None, values: list = None, resolution: int = None, cutoff: int = None, cutoffValue: str = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', includeRawOutput: bool = 'False', includeConclusion: bool = 'False', includeSolution: bool = 'False', includeOthers: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch asset vulnerability statistics base on criteria (DEV)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. name (list) – Restrict search to specific asset name startTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (start timestamp). endTimestamp (int) – Restrict search to a time frame based on the set TimeFieldStrategy (end timestamp). keywords (list) – Search for keywords. keywordMatchStrategy (str) – Defines the MatchStrategy for keywords (default match all keywords). timeMatchStrategy (str) – Defines how strict to match against different timestamps (all/any) using start and end timestamp (default any) hostID (list) – Restrict search to specific host UUIDs. serviceID (list) – Restrict search to specific service UUIDs. businessProcessID (list) – Restrict search to specific business process UUIDs. ipRange (list) – Restrict search to entities related to these IP-addresses (may specify single IPs, IP networks or IP ranges. applicationPort (list) – Restrict to applications listening on specific ports. applicationProtocol (list) – Restrict to applications by transport protocol name. cpe (list) – Restrict to applications or hosts by CPE. hostCPE (list) – Restrict to hosts by CPE. applicationCPE (list) – Restrict to applications by CPE. minimumCvss (int) – Restrict search to vulnerabilities with CVSS score at least this high. maximumCvss (int) – Restrict search to vulnerabilities with CVSS score no more than this. severity (list) – Restrict search to specified severity levels. resolutionCode (list) – Restrict search to specific resolution codes. vulnerabilityReference (list) – Restrict to vulnerabilities identified by vulnerability reference. vulnerabilityID (list) – Restrict to vulnerabilities identified by vulnerability ID. timeFieldStrategy (list) – Defines which timestamps will be included in the search (default lastUpdatedTimestamp). keywordFieldStrategy (list) – Defines which fields will be searched by keywords (default all supported fields). groupBy (list) – Specify which fields will be grouped by in stats values (list) – Specify which values will be included in stats (default vulnerabilities) resolution (int) – Stats resolution period in milliseconds, if is 0 means to generate non-timeline statistics cutoff (int) – Reduce stats keys to the cutoff amount of keys that has largest hit count, default 0 means no reduce cutoffValue (str) – Specify which value to be cutoff on (default vulnerabilities) sortBy (list) – List of properties to sort by (prefix with “-” to sort descending). includeFlags (list) – Only include objects which have includeFlags set. excludeFlags (list) – Exclude objects which have excludeFlags set. includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). includeRawOutput (bool) – Include vulnerability rawOutput in result (default false) includeConclusion (bool) – Include vulnerability conclusion in result (default false) includeSolution (bool) – Include vulnerability solution in result (default false) includeOthers (bool) – If reduce (cutoff >0), true means remaining keys (other than cutoff keys) are collected into an “other” key, default false
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 308, “limit”: 722, “responseCode”: 200, “count”: 679, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Room customer nation happen bed rise left.”, “messageTemplate”: “Speech dinner decide agent plan pick ready card.”, “field”: “Throw kitchen room environmental face.”, “parameter”: {}, “timestamp”: 1238820889}], “currentPage”: 116, “size”: 442}

`api.assets.v1.vulnerability.` `update_asset_vulnerability`(id: str, addReferences: list = None, deleteReferences: list = None, name: str = None, description: str = None, conclusion: str = None, solution: str = None, rawOutput: str = None, cvss: int = None, severity: str = None, addProperties: dict = None, deleteProperties: list = None, source: str = 'USER', exploitAvailable: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Updates an existing AssetVulnerability. (PUBLIC)

  Return type: | `dict`
  Parameters: | id (str) – AssetVulnerability ID addReferences (list) – Add references to vulnerability (e.g. CVE number). deleteReferences (list) – Delete references from vulnerability. name (str) – Change vulnerability name. Will be sanitized and no line break allowed. description (str) – Change vulnerability description. Will be sanitized. conclusion (str) – Change vulnerability summary. Will be sanitized. solution (str) – Change vulnerability solution. Will be sanitized. rawOutput (str) – Change raw output from vulnerability scan. Will be sanitized. cvss (int) – Change CVSS score of vulnerability (range from 0 to 10). severity (str) – Change severity level of vulnerability. addProperties (dict) – Add custom properties (updates a property if key already exists). => [sw{}$-().[]“‘_/,*+#:@!?;]* deleteProperties (list) – Delete custom properties by key. source (str) – Source of the request. (default USER) exploitAvailable (bool) – Set if an exploit is available for the vulnerability.
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 64, “limit”: 544, “responseCode”: 200, “count”: 532, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Nature draw continue protect.”, “messageTemplate”: “Kitchen notice into draw.”, “field”: “Hospital great other represent model people decide whatever.”, “parameter”: {}, “timestamp”: 1221989607}], “currentPage”: 170, “size”: 719}

## Module contents